pyxmpp2.mainloop.interfaces.HandlerReady

Package pyxmpp2 :: Package mainloop :: Module interfaces :: Class HandlerReady |
[hide private]

# Class HandlerReady

Returned by the IOHandler.prepare method when the object is ready to handle I/O events and doesn't need further calls to the IOHandler.prepare method.

Instance Methods | [hide private]
__repr__(self) repr(x) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)